@@ -1,4 +1,5 @@
 pub mod buffer;
+pub mod encoding;
 pub mod reader;
 pub mod writer;
 
@@ -8,6 +9,11 @@ pub use reader::BufferMutReader;
 pub use reader::BufferReader;
 pub use writer::BufferWriter;
 
+pub trait FieldMetadata {
+    fn field_type(&self) -> &'static [u8];
+    fn field_name(&self) -> &'static [&'static str];
+}
+
 #[cfg(test)]
 mod tests {
     use crate::{types, Buffer};
